@@ -5,7 +5,7 @@ package Sidef::Math::Math {
 
     use parent qw(
       Sidef::Object::Object
-      );
+    );
 
     use Sidef::Types::Number::Number;
 
@@ -13,35 +13,9 @@ package Sidef::Math::Math {
         bless {}, __PACKAGE__;
     }
 
-    sub _binsplit {    # not used anymore, but let's keep it around anyway
-        my ($arr, $method) = @_;
-
-        my $sub = sub {
-            my ($s, $n, $m) = @_;
-
-            $n == $m
-              ? $s->[$n]
-              : __SUB__->($s, $n, ($n + $m) >> 1)->$method(__SUB__->($s, (($n + $m) >> 1) + 1, $m));
-        };
-
-        my $end = $#$arr;
-
-        if ($end < 0) {
-            return undef;
-        }
-
-        if ($end <= 1e5) {
-            return $sub->($arr, 0, $end);
-        }
-
-        my @partial;
-
-        while (@$arr) {
-            my @head = splice(@$arr, 0, 1e5);
-            push @partial, $sub->(\@head, 0, $#head);
-        }
-
-        __SUB__->(\@partial, $method);
+    sub binsplit {
+        my ($self, $block, @list) = @_;
+        Sidef::Types::Number::Number::_binsplit(\@list, $block);
     }
 
     sub gcd {
@@ -80,7 +54,7 @@ package Sidef::Math::Math {
         my ($self, @list) = @_;
 
         my $sum = Sidef::Types::Number::Number::sum(@list);
-        my $n   = Sidef::Types::Number::Number->_set_uint(scalar(@list));
+        my $n   = Sidef::Types::Number::Number::_set_int(scalar(@list));
 
         $sum->div($n);
     }
@@ -91,7 +65,7 @@ package Sidef::Math::Math {
         my ($self, @list) = @_;
 
         my $prod = Sidef::Types::Number::Number::prod(@list);
-        my $n    = Sidef::Types::Number::Number->_set_uint(scalar(@list));
+        my $n    = Sidef::Types::Number::Number::_set_int(scalar(@list));
 
         $prod->root($n);
     }
@@ -100,11 +74,36 @@ package Sidef::Math::Math {
         my ($self, @list) = @_;
 
         my $sum = Sidef::Types::Number::Number::sum(map { $_->inv } @list);
-        my $n   = Sidef::Types::Number::Number->_set_uint(scalar(@list));
+        my $n   = Sidef::Types::Number::Number::_set_int(scalar(@list));
 
         $n->div($sum);
     }
 
+    sub smooth_numbers {
+        my ($self, @primes) = @_;
+
+        my @s = map { [Sidef::Types::Number::Number::ONE] } @primes;
+
+        Sidef::Object::Enumerator->new(
+            Sidef::Types::Block::Block->new(
+                code => sub {
+                    my ($callback) = @_;
+
+                    while (1) {
+                        my $n = Sidef::Types::Number::Number::min(map { $_->[0] } @s);
+
+                        for my $i (0 .. $#primes) {
+                            shift(@{$s[$i]}) if $s[$i][0]->eq($n);
+                            push(@{$s[$i]}, $n->mul($primes[$i]));
+                        }
+
+                        $callback->run($n);
+                    }
+                }
+            )
+        );
+    }
+
     sub chinese {
         my ($self, @arrs) = @_;
 
@@ -122,18 +121,13 @@ package Sidef::Math::Math {
         }
 
         my $res = eval { Math::Prime::Util::GMP::chinese(@pairs) } // return Sidef::Types::Number::Number->nan;
-
-        if ($res < Sidef::Types::Number::Number::ULONG_MAX and $res >= 0) {
-            return Sidef::Types::Number::Number->_set_uint($res);
-        }
-
-        Sidef::Types::Number::Number->_set_str('int', $res);
+        Sidef::Types::Number::Number::_set_int($res);
     }
 
     sub range_sum {
         my ($self, $from, $to, $step) = @_;
         $step //= Sidef::Types::Number::Number::ONE;
-        state $two = Sidef::Types::Number::Number->_set_uint(2);
+        state $two = Sidef::Types::Number::Number::_set_int(2);
         ($from->add($to))->mul($to->sub($from)->div($step)->add(Sidef::Types::Number::Number::ONE))->div($two);
     }
 
@@ -153,7 +147,7 @@ package Sidef::Math::Math {
         my $sum  = $to->sub($from)->abs;
         my $dist = $num->sub($to)->abs;
 
-        state $hundred = Sidef::Types::Number::Number->_set_uint(100);
+        state $hundred = Sidef::Types::Number::Number::_set_int(100);
         ($sum->sub($dist))->div($sum)->mul($hundred);
     }
 }
