@@ -71,7 +71,7 @@ package Sidef::Perl::Perl {
                 if (Scalar::Util::looks_like_number($val)) {
 
                     if ($val =~ /e/) {    # parse as float when in exponential notation
-                        return Sidef::Types::Number::Number->_set_str('float', "$val");
+                        return Sidef::Types::Number::Number::_set_str('float', "$val");
                     }
 
                     return Sidef::Types::Number::Number->new("$val");
