@@ -37,7 +37,7 @@ package Sidef::Types::Array::Matrix {
         my ($self) = @_;
         my $rows = $#{$self};
         $rows < 0 and return ((Sidef::Types::Number::Number::ZERO) x 2);
-        (Sidef::Types::Number::Number->_set_uint($rows + 1), Sidef::Types::Number::Number->_set_uint($#{$self->[0]} + 1));
+        (Sidef::Types::Number::Number::_set_int($rows + 1), Sidef::Types::Number::Number::_set_int($#{$self->[0]} + 1));
     }
 
     sub build {
@@ -55,10 +55,10 @@ package Sidef::Types::Array::Matrix {
 #<<<
         bless [
             map {
-                my $i = Sidef::Types::Number::Number->_set_uint($_);
+                my $i = Sidef::Types::Number::Number::_set_int($_);
                 bless([map {
                     $block->run(
-                        $i, Sidef::Types::Number::Number->_set_uint($_)
+                        $i, Sidef::Types::Number::Number::_set_int($_)
                     );
                 } 0 .. $m-1], 'Sidef::Types::Array::Array')
             } 0 .. $n-1
@@ -433,7 +433,7 @@ package Sidef::Types::Array::Matrix {
         my ($A, $pow, $mod) = @_;
 
         if ($pow->is_neg) {
-            $A   = $A->inv;     # TODO: implement invmod
+            $A   = $A->invmod($mod);
             $pow = $pow->abs;
         }
 
@@ -560,6 +560,20 @@ package Sidef::Types::Array::Matrix {
     *inv     = \&invert;
     *inverse = \&invert;
 
+    sub invmod {
+        my ($self, $mod) = @_;
+
+        my $A = $self->inv;
+
+        foreach my $row (@$A) {
+            foreach my $i (0 .. $#{$row}) {
+                $row->[$i] = $row->[$i]->mod($mod);
+            }
+        }
+
+        return $A;
+    }
+
     sub determinant {
         my ($self) = @_;
 
@@ -765,7 +779,7 @@ package Sidef::Types::Array::Matrix {
     sub column_count {
         my ($A) = @_;
         @$A || return Sidef::Types::Number::Number::ZERO;
-        Sidef::Types::Number::Number->_set_uint(scalar @{$A->[0]});
+        Sidef::Types::Number::Number::_set_int(scalar @{$A->[0]});
     }
 
     *column_len  = \&column_count;
@@ -776,7 +790,7 @@ package Sidef::Types::Array::Matrix {
 
     sub row_count {
         my ($A) = @_;
-        Sidef::Types::Number::Number->_set_uint(scalar @$A);
+        Sidef::Types::Number::Number::_set_int(scalar @$A);
     }
 
     *row_len  = \&row_count;
