@@ -184,12 +184,14 @@ package Sidef::Types::Range::RangeNumber {
             return Sidef::Types::Number::Number::ZERO;
         }
 
-        state $two = Sidef::Types::Number::Number->_set_uint(2);
+        state $two = Sidef::Types::Number::Number::_set_int(2);
 
         $n = $n->floor;
         $n->inc->mul($z->mul($n)->add($x->mul($two)))->div($two);
     }
 
+    *Σ = \&sum;
+
     sub avg_by {
         my ($self, $block) = @_;
         $self->sum_by($block)->div($self->len);
@@ -227,6 +229,8 @@ package Sidef::Types::Range::RangeNumber {
         Sidef::Types::Number::Number::prod($self->to_list);
     }
 
+    *Π = \&prod;
+
     sub lcm_by {
         my ($self, $block) = @_;
         $block //= Sidef::Types::Block::Block::IDENTITY;
@@ -319,6 +323,163 @@ package Sidef::Types::Range::RangeNumber {
         $self->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_prime }));
     }
 
+    sub squarefree {
+        my ($self) = @_;
+
+        if ($self->{step}->abs->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            if ($self->{step}->is_neg) {
+                return Sidef::Types::Number::Number::squarefree($right, $left)->flip;
+            }
+
+            return Sidef::Types::Number::Number::squarefree($left, $right);
+        }
+
+        $self->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_squarefree }));
+    }
+
+    sub semiprimes {
+        my ($self) = @_;
+
+        if ($self->{step}->abs->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            if ($self->{step}->is_neg) {
+                return Sidef::Types::Number::Number::semiprimes($right, $left)->flip;
+            }
+
+            return Sidef::Types::Number::Number::semiprimes($left, $right);
+        }
+
+        $self->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_semiprime }));
+    }
+
+    sub each_prime {
+        my ($self, $block) = @_;
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_prime($left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_prime }))->each($block);
+        return $self;
+    }
+
+    sub each_semiprime {
+        my ($self, $block) = @_;
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_semiprime($left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_semiprime }))->each($block);
+        return $self;
+    }
+
+    sub each_squarefree {
+        my ($self, $block) = @_;
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_squarefree($left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_squarefree }))->each($block);
+        return $self;
+    }
+
+    sub each_powerful {
+        my ($self, $k, $block) = @_;
+
+        $k = Sidef::Types::Number::Number->new($k);
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_powerful($k, $left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_powerful($k) }))->each($block);
+        return $self;
+    }
+
+    sub each_almost_prime {
+        my ($self, $k, $block) = @_;
+
+        $k = Sidef::Types::Number::Number->new($k);
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_almost_prime($k, $left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_almost_prime($k) }))->each($block);
+        return $self;
+    }
+
+    sub each_omega_prime {
+        my ($self, $k, $block) = @_;
+
+        $k = Sidef::Types::Number::Number->new($k);
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_omega_prime($k, $left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_omega_prime($k) }))->each($block);
+        return $self;
+    }
+
+    sub each_squarefree_almost_prime {
+        my ($self, $k, $block) = @_;
+
+        $k = Sidef::Types::Number::Number->new($k);
+
+        if ($self->{step}->is_one) {
+
+            my $left  = Sidef::Types::Number::Number->new($self->{from});
+            my $right = Sidef::Types::Number::Number->new($self->{to});
+
+            Sidef::Types::Number::Number::each_squarefree_almost_prime($k, $left, $right, $block);
+            return $self;
+        }
+
+        $self->lazy->grep(Sidef::Types::Block::Block->new(code => sub { $_[0]->is_squarefree && $_[0]->is_almost_prime($k) }))
+          ->each($block);
+        return $self;
+    }
+
     sub dump {
         my ($self) = @_;
         Sidef::Types::String::String->new("$self");
