@@ -514,7 +514,7 @@ package Sidef::Types::String::String {
 
     sub index {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number->_set_int(
+        Sidef::Types::Number::Number::_set_int(
                                                defined($pos)
                                                ? CORE::index($$self, "$substr", CORE::int($pos))
                                                : CORE::index($$self, "$substr")
@@ -523,7 +523,7 @@ package Sidef::Types::String::String {
 
     sub rindex {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number->_set_int(
+        Sidef::Types::Number::Number::_set_int(
                                                defined($pos)
                                                ? CORE::rindex($$self, "$substr", CORE::int($pos))
                                                : CORE::rindex($$self, "$substr")
@@ -534,7 +534,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
         $$self eq ''
           ? undef
-          : Sidef::Types::Number::Number->_set_uint(CORE::ord($$self));
+          : Sidef::Types::Number::Number::_set_int(CORE::ord($$self));
     }
 
     sub reverse {
@@ -755,7 +755,7 @@ package Sidef::Types::String::String {
     sub digits {
         my ($self) = @_;
         Sidef::Types::Array::Array->new(
-                            [map { Sidef::Types::Number::Number->_set_uint($_) } grep { /^[0-9]\z/ } CORE::split(//, $$self)]);
+                             [map { Sidef::Types::Number::Number::_set_int($_) } grep { /^[0-9]\z/ } CORE::split(//, $$self)]);
     }
 
     sub each_number {
@@ -777,7 +777,7 @@ package Sidef::Types::String::String {
         Sidef::Types::Array::Array->new(
             [
              map {
-                 Sidef::Types::Number::Number->_set_uint(CORE::ord(bytes::substr($string, $_, 1)))
+                 Sidef::Types::Number::Number::_set_int(CORE::ord(bytes::substr($string, $_, 1)))
                } 0 .. bytes::length($string) - 1
             ]
         );
@@ -790,7 +790,7 @@ package Sidef::Types::String::String {
 
         require bytes;
         foreach my $i (0 .. bytes::length($string) - 1) {
-            $code->run(Sidef::Types::Number::Number->_set_uint(CORE::ord bytes::substr($string, $i, 1)));
+            $code->run(Sidef::Types::Number::Number::_set_int(CORE::ord bytes::substr($string, $i, 1)));
         }
 
         $self;
@@ -1042,7 +1042,7 @@ package Sidef::Types::String::String {
     }
 
     sub chars_length {
-        Sidef::Types::Number::Number->_set_uint(CORE::length(${$_[0]}));
+        Sidef::Types::Number::Number::_set_int(CORE::length(${$_[0]}));
     }
 
     *len       = \&chars_length;
@@ -1051,7 +1051,7 @@ package Sidef::Types::String::String {
     *size      = \&chars_length;
 
     sub graphs_length {
-        Sidef::Types::Number::Number->_set_uint(scalar(() = ${$_[0]} =~ /\X/g));
+        Sidef::Types::Number::Number::_set_int(scalar(() = ${$_[0]} =~ /\X/g));
     }
 
     *graphs_len = \&graphs_length;
@@ -1060,7 +1060,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
 
         require bytes;
-        Sidef::Types::Number::Number->_set_uint(bytes::length($$self));
+        Sidef::Types::Number::Number::_set_int(bytes::length($$self));
     }
 
     *bytes_len = \&bytes_length;
@@ -1086,7 +1086,7 @@ package Sidef::Types::String::String {
             }
         }
 
-        Sidef::Types::Number::Number->_set_int($d[-1][-1]);
+        Sidef::Types::Number::Number::_set_int($d[-1][-1]);
     }
 
     *lev   = \&levenshtein;
@@ -1200,18 +1200,18 @@ package Sidef::Types::String::String {
         if (ref($arg) eq 'Sidef::Types::Regex::Regex') {
             my $regex = $arg->{regex};
             ++$counter while $s =~ /$regex/g;
-            return Sidef::Types::Number::Number->_set_uint($counter);
+            return Sidef::Types::Number::Number::_set_int($counter);
         }
         elsif (ref($arg) eq 'Sidef::Types::Block::Block') {
             foreach my $char (split //, $s) {
                 ++$counter if $arg->run(bless \$char);
             }
-            return Sidef::Types::Number::Number->_set_uint($counter);
+            return Sidef::Types::Number::Number::_set_int($counter);
         }
 
         my $ss = "$arg";
         ++$counter while $s =~ /\Q$ss\E/g;
-        Sidef::Types::Number::Number->_set_uint($counter);
+        Sidef::Types::Number::Number::_set_int($counter);
     }
 
     sub overlaps {
